[nautilus-actions/file-manager-actions] NAIExporter interface is renamed to FMAIExporter



commit 4187c77c6b8cf57c47cebabd8ccf707bce92408f
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 22:09:23 2015 +0200

    NAIExporter interface is renamed to FMAIExporter

 src/api/Makefile.am                          |    2 +-
 src/api/fma-extension.h                      |    2 +-
 src/api/{na-iexporter.h => fma-iexporter.h}  |  156 +++++++++++++-------------
 src/core/Makefile.am                         |    2 +-
 src/core/{na-iexporter.c => fma-iexporter.c} |   34 +++---
 src/core/na-export-format.c                  |   12 +-
 src/core/na-export-format.h                  |    6 +-
 src/core/na-exporter.c                       |   90 ++++++++--------
 src/core/na-exporter.h                       |    8 +-
 src/core/na-pivot.h                          |    2 +-
 src/io-desktop/nadp-desktop-provider.c       |   22 ++--
 src/io-desktop/nadp-formats.c                |   24 ++--
 src/io-desktop/nadp-formats.h                |    4 +-
 src/io-desktop/nadp-writer.c                 |   38 +++---
 src/io-desktop/nadp-writer.h                 |    6 +-
 src/io-xml/naxml-formats.c                   |   20 ++--
 src/io-xml/naxml-formats.h                   |    4 +-
 src/io-xml/naxml-provider.c                  |   24 ++--
 src/io-xml/naxml-writer.c                    |   46 ++++----
 src/io-xml/naxml-writer.h                    |    6 +-
 src/utils/nautilus-actions-print.c           |    2 +-
 21 files changed, 255 insertions(+), 255 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index 73e980f..3e7e325 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -31,7 +31,7 @@ api_include_HEADERS = \
        fma-extension.h                                                                         \
        \
        fma-dbus.h                                                                                      \
-       na-iexporter.h                                                                          \
+       fma-iexporter.h                                                                         \
        na-iimporter.h                                                                          \
        na-ifactory-provider.h                                                          \
        na-ifactory-provider-provider.h                                         \
diff --git a/src/api/fma-extension.h b/src/api/fma-extension.h
index 7696292..7ceacb3 100644
--- a/src/api/fma-extension.h
+++ b/src/api/fma-extension.h
@@ -61,7 +61,7 @@
  *        </title>
  *        <para>
  *          This extension is provided via the public
- *          <link linkend="NAIExporter">NAIExporter</link>
+ *          <link linkend="FMAIExporter">FMAIExporter</link>
  *          interface; it takes care of exporting menus and actions
  *          to the filesystem from the &prodname; Configuration Tool
  *          user interface.
diff --git a/src/api/na-iexporter.h b/src/api/fma-iexporter.h
similarity index 77%
rename from src/api/na-iexporter.h
rename to src/api/fma-iexporter.h
index e582b3c..b3826a1 100644
--- a/src/api/na-iexporter.h
+++ b/src/api/fma-iexporter.h
@@ -27,16 +27,16 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_IEXPORTER_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_IEXPORTER_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_IEXPORTER_H__
+#define __FILE_MANAGER_ACTIONS_API_IEXPORTER_H__
 
 /**
  * SECTION: iexporter
- * @title: NAIExporter
+ * @title: FMAIExporter
  * @short_description: The Export Interface
- * @include: file-manager-actions/na-iexporter.h
+ * @include: file-manager-actions/fma-iexporter.h
  *
- * The #NAIExporter interface exports items to the outside world. Each
+ * The #FMAIExporter interface exports items to the outside world. Each
  * implementation may provide one or more formats.
  *
  * <refsect2>
@@ -110,7 +110,7 @@
  * <refsect2>
  *  <title>Versions historic</title>
  *  <table>
- *    <title>Historic of the versions of the #NAIExporter interface</title>
+ *    <title>Historic of the versions of the #FMAIExporter interface</title>
  *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
  *      <colspec colname="na-version" />
  *      <colspec colname="api-version" />
@@ -119,7 +119,7 @@
  *      <thead>
  *        <row>
  *          <entry>&prodname; version</entry>
- *          <entry>#NAIExporter interface version</entry>
+ *          <entry>#FMAIExporter interface version</entry>
  *          <entry></entry>
  *          <entry></entry>
  *        </row>
@@ -148,24 +148,24 @@
 
 G_BEGIN_DECLS
 
-#define NA_TYPE_IEXPORTER                      ( na_iexporter_get_type())
-#define NA_IEXPORTER( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_TYPE_IEXPORTER, 
NAIExporter ))
-#define NA_IS_IEXPORTER( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_IEXPORTER ))
-#define NA_IEXPORTER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
NA_TYPE_IEXPORTER, NAIExporterInterface ))
+#define FMA_TYPE_IEXPORTER                      ( fma_iexporter_get_type())
+#define FMA_IEXPORTER( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, FMA_TYPE_IEXPORTER, 
FMAIExporter ))
+#define FMA_IS_IEXPORTER( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, FMA_TYPE_IEXPORTER ))
+#define FMA_IEXPORTER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), 
FMA_TYPE_IEXPORTER, FMAIExporterInterface ))
 
-typedef struct _NAIExporter                    NAIExporter;
-typedef struct _NAIExporterInterfacePrivate    NAIExporterInterfacePrivate;
+typedef struct _FMAIExporter                    FMAIExporter;
+typedef struct _FMAIExporterInterfacePrivate    FMAIExporterInterfacePrivate;
 
 #ifdef NA_ENABLE_DEPRECATED
 /**
- * NAIExporterFormat:
+ * FMAIExporterFormat:
  * @format:      format identifier (ascii).
  * @label:       short label to be displayed in dialog (UTF-8 localized)
  * @description: full description of the format (UTF-8 localized);
  *               mainly used in the export assistant.
  *
  * This structure describes a supported output format.
- * It must be provided by each #NAIExporter implementation
+ * It must be provided by each #FMAIExporter implementation
  * (see e.g. <filename>src/io-xml/naxml-formats.c</filename>).
  *
  * When listing available export formats, the instance returns a #GList
@@ -178,10 +178,10 @@ typedef struct {
        gchar     *label;
        gchar     *description;
 }
-       NAIExporterFormat;
+       FMAIExporterFormat;
 
 /**
- * NAIExporterFileParms:
+ * FMAIExporterFileParms:
  * @version:  [in] version of this structure;
  *                 since structure version 1.
  * @exported: [in] exported NAObjectItem-derived object;
@@ -198,7 +198,7 @@ typedef struct {
  *                 since structure version 1.
  *
  * The structure that the implementation receives as a parameter of
- * #NAIExporterInterface.to_file () interface method.
+ * #FMAIExporterInterface.to_file () interface method.
  *
  * Deprecated: 3.2
  */
@@ -210,10 +210,10 @@ typedef struct {
        gchar        *basename;
        GSList       *messages;
 }
-       NAIExporterFileParms;
+       FMAIExporterFileParms;
 
 /**
- * NAIExporterBufferParms:
+ * FMAIExporterBufferParms:
  * @version:  [in] version of this structure;
  *                 since structure version 1.
  * @exported: [in] exported NAObjectItem-derived object;
@@ -228,7 +228,7 @@ typedef struct {
  *                 since structure version 1.
  *
  * The structure that the plugin receives as a parameter of
- * #NAIExporterInterface.to_buffer () interface method.
+ * #FMAIExporterInterface.to_buffer () interface method.
  *
  * Deprecated: 3.2
  */
@@ -239,16 +239,16 @@ typedef struct {
        gchar        *buffer;
        GSList       *messages;
 }
-       NAIExporterBufferParms;
+       FMAIExporterBufferParms;
 
 #endif /* NA_ENABLE_DEPRECATED */
 
 /**
- * NAIExporterFormatv2:
- * @version:     the version of this #NAIExporterFormatv2 structure;
+ * FMAIExporterFormatv2:
+ * @version:     the version of this #FMAIExporterFormatv2 structure;
  *               equals to 2;
  *               since structure version 1.
- * @provider:    the #NAIExporter provider for this format;
+ * @provider:    the #FMAIExporter provider for this format;
  *               since structure version 2.
  * @format:      format identifier (ascii, allocated by the FileManager-Actions team);
  *               since structure version 2.
@@ -262,7 +262,7 @@ typedef struct {
  *               since structure version 2.
  *
  * This structure describes a supported output format.
- * It must be provided by each #NAIExporter implementation
+ * It must be provided by each #FMAIExporter implementation
  * (see e.g. <filename>src/io-xml/naxml-formats.c</filename>).
  *
  * When listing available export formats, the @provider must return a #GList
@@ -271,7 +271,7 @@ typedef struct {
  * <refsect2>
  *  <title>Versions historic</title>
  *  <table>
- *    <title>Historic of the versions of the #NAIExporterFormatv2 structure</title>
+ *    <title>Historic of the versions of the #FMAIExporterFormatv2 structure</title>
  *    <tgroup rowsep="1" colsep="1" align="center" cols="3">
  *      <colspec colname="na-version" />
  *      <colspec colname="api-version" />
@@ -279,7 +279,7 @@ typedef struct {
  *      <thead>
  *        <row>
  *          <entry>&prodname; version</entry>
- *          <entry>#NAIExporterFormatv2 structure version</entry>
+ *          <entry>#FMAIExporterFormatv2 structure version</entry>
  *          <entry></entry>
  *        </row>
  *      </thead>
@@ -303,16 +303,16 @@ typedef struct {
  */
 typedef struct {
        guint        version;
-       NAIExporter *provider;
+       FMAIExporter *provider;
        gchar       *format;
        gchar       *label;
        gchar       *description;
        GdkPixbuf   *pixbuf;
 }
-       NAIExporterFormatv2;
+       FMAIExporterFormatv2;
 
 /**
- * NAIExporterFileParmsv2:
+ * FMAIExporterFileParmsv2:
  * @version:  [in] version of this structure;
  *                 equals to 2;
  *                 since structure version 1.
@@ -333,7 +333,7 @@ typedef struct {
  *                 since structure version 1.
  *
  * The structure that the plugin receives as a parameter of
- * #NAIExporterInterface.to_file () interface method.
+ * #FMAIExporterInterface.to_file () interface method.
  *
  * Since: 3.2
  */
@@ -346,10 +346,10 @@ typedef struct {
        gchar        *basename;
        GSList       *messages;
 }
-       NAIExporterFileParmsv2;
+       FMAIExporterFileParmsv2;
 
 /**
- * NAIExporterBufferParmsv2:
+ * FMAIExporterBufferParmsv2:
  * @version:  [in] version of this structure;
  *                 equals to 2;
  *                 since structure version 1.
@@ -368,7 +368,7 @@ typedef struct {
  *                 since structure version 1.
  *
  * The structure that the plugin receives as a parameter of
- * #NAIExporterInterface.to_buffer () interface method.
+ * #FMAIExporterInterface.to_buffer () interface method.
  *
  * Since: 3.2
  */
@@ -380,10 +380,10 @@ typedef struct {
        gchar        *buffer;
        GSList       *messages;
 }
-       NAIExporterBufferParmsv2;
+       FMAIExporterBufferParmsv2;
 
 /**
- * NAIExporterInterface:
+ * FMAIExporterInterface:
  * @get_version:  [should] returns the version of this interface the plugin implements.
  * @get_name:     [should] returns the public plugin name.
  * @get_formats:  [should] returns the list of supported formats.
@@ -391,17 +391,17 @@ typedef struct {
  * @to_file:      [should] exports an item to a file.
  * @to_buffer:    [should] exports an item to a buffer.
  *
- * This defines the interface that a #NAIExporter should implement.
+ * This defines the interface that a #FMAIExporter should implement.
  */
 typedef struct {
        /*< private >*/
        GTypeInterface               parent;
-       NAIExporterInterfacePrivate *private;
+       FMAIExporterInterfacePrivate *private;
 
        /*< public >*/
        /**
         * get_version:
-        * @instance: this NAIExporter instance.
+        * @instance: this FMAIExporter instance.
         *
         * FileManager-Actions calls this method each time it needs to know
         * which version of this interface the plugin implements.
@@ -417,11 +417,11 @@ typedef struct {
         *
         * Since: 2.30
         */
-       guint   ( *get_version )( const NAIExporter *instance );
+       guint   ( *get_version )( const FMAIExporter *instance );
 
        /**
         * get_name:
-        * @instance: this NAIExporter instance.
+        * @instance: this FMAIExporter instance.
         *
         * Return value: if implemented, the method should return the name to be
         * displayed, as a newly allocated string which will be g_free() by the
@@ -434,11 +434,11 @@ typedef struct {
         *
         * Since: 2.30
         */
-       gchar * ( *get_name )   ( const NAIExporter *instance );
+       gchar * ( *get_name )   ( const FMAIExporter *instance );
 
        /**
         * get_formats:
-        * @instance: this NAIExporter instance.
+        * @instance: this FMAIExporter instance.
         *
         * For its own internal needs, FileManager-Actions requires each export
         * format has its own unique identifier (in fact, just a small ASCII
@@ -451,15 +451,15 @@ typedef struct {
         *
         * Return value:
         * - Interface v1:
-        *   a null-terminated list of NAIExporterFormat structures
-        *   which describes the formats supported by this NAIExporter
+        *   a null-terminated list of FMAIExporterFormat structures
+        *   which describes the formats supported by this FMAIExporter
         *   provider.
-        *   The returned list is owned by the NAIExporter provider,
+        *   The returned list is owned by the FMAIExporter provider,
         *   and should not be freed nor released by the caller.
         *
         * - Interface v2:
-        *   a GList of NAIExporterFormatv2 structures
-        *   which describes the formats supported by this NAIExporter
+        *   a GList of FMAIExporterFormatv2 structures
+        *   which describes the formats supported by this FMAIExporter
         *   provider.
         *   The caller should then invoke the free_formats() method
         *   in order the provider be able to release the resources
@@ -469,74 +469,74 @@ typedef struct {
         *
         * Since: 2.30
         */
-       void *  ( *get_formats )( const NAIExporter *instance );
+       void *  ( *get_formats )( const FMAIExporter *instance );
 
        /**
         * free_formats:
-        * @instance: this NAIExporter instance.
-        * @formats: a null-terminated list of NAIExporterFormatv2 structures,
+        * @instance: this FMAIExporter instance.
+        * @formats: a null-terminated list of FMAIExporterFormatv2 structures,
         *  as returned by get_formats() method above.
         *
         * Free the resources allocated to the @formats list.
         *
         * Since: 3.2
         */
-       void    ( *free_formats )( const NAIExporter *instance, GList *formats );
+       void    ( *free_formats )( const FMAIExporter *instance, GList *formats );
 
        /**
         * to_file:
-        * @instance: this NAIExporter instance.
-        * @parms: a NAIExporterFileParmsv2 structure.
+        * @instance: this FMAIExporter instance.
+        * @parms: a FMAIExporterFileParmsv2 structure.
         *
         * Exports the specified 'exported' to the target 'folder' in the required
         * 'format'.
         *
-        * Return value: the NAIExporterExportStatus status of the operation.
+        * Return value: the FMAIExporterExportStatus status of the operation.
         *
         * Since: 2.30
         */
-       guint   ( *to_file )    ( const NAIExporter *instance, NAIExporterFileParmsv2 *parms );
+       guint   ( *to_file )    ( const FMAIExporter *instance, FMAIExporterFileParmsv2 *parms );
 
        /**
         * to_buffer:
-        * @instance: this NAIExporter instance.
-        * @parms: a NAIExporterFileParmsv2 structure.
+        * @instance: this FMAIExporter instance.
+        * @parms: a FMAIExporterFileParmsv2 structure.
         *
         * Exports the specified 'exported' to a newly allocated 'buffer' in
         * the required 'format'. The allocated 'buffer' will be g_free()
         * by the caller.
         *
-        * Return value: the NAIExporterExportStatus status of the operation.
+        * Return value: the FMAIExporterExportStatus status of the operation.
         *
         * Since: 2.30
         */
-       guint   ( *to_buffer )  ( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms );
+       guint   ( *to_buffer )  ( const FMAIExporter *instance, FMAIExporterBufferParmsv2 *parms );
 }
-       NAIExporterInterface;
+       FMAIExporterInterface;
 
 /**
- * NAIExporterExportStatus:
- * @NA_IEXPORTER_CODE_OK:              export OK.
- * @NA_IEXPORTER_CODE_INVALID_ITEM:    exported item was found invalid.
- * @NA_IEXPORTER_CODE_INVALID_TARGET:  selected target was found invalid.
- * @NA_IEXPORTER_CODE_INVALID_FORMAT:  asked format was found invalid.
- * @NA_IEXPORTER_CODE_UNABLE_TO_WRITE: unable to write the item.
- * @NA_IEXPORTER_CODE_ERROR:           other undetermined error.
+ * FMAIExporterExportStatus:
+ * @FMA_IEXPORTER_CODE_OK:              export OK.
+ * @FMA_IEXPORTER_CODE_INVALID_ITEM:    exported item was found invalid.
+ * @FMA_IEXPORTER_CODE_INVALID_TARGET:  selected target was found invalid.
+ * @FMA_IEXPORTER_CODE_INVALID_FORMAT:  asked format was found invalid.
+ * @FMA_IEXPORTER_CODE_UNABLE_TO_WRITE: unable to write the item.
+ * @FMA_IEXPORTER_CODE_ERROR:           other undetermined error.
  *
  * The reasons for which an item may not have been exported
  */
 typedef enum {
-       NA_IEXPORTER_CODE_OK = 0,
-       NA_IEXPORTER_CODE_INVALID_ITEM,
-       NA_IEXPORTER_CODE_INVALID_TARGET,
-       NA_IEXPORTER_CODE_INVALID_FORMAT,
-       NA_IEXPORTER_CODE_UNABLE_TO_WRITE,
-       NA_IEXPORTER_CODE_ERROR,
+       FMA_IEXPORTER_CODE_OK = 0,
+       FMA_IEXPORTER_CODE_INVALID_ITEM,
+       FMA_IEXPORTER_CODE_INVALID_TARGET,
+       FMA_IEXPORTER_CODE_INVALID_FORMAT,
+       FMA_IEXPORTER_CODE_UNABLE_TO_WRITE,
+       FMA_IEXPORTER_CODE_ERROR,
 }
-       NAIExporterExportStatus;
+       FMAIExporterExportStatus;
 
-GType na_iexporter_get_type( void );
+GType fma_iexporter_get_type( void );
 
 G_END_DECLS
 
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_IEXPORTER_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_IEXPORTER_H__ */
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 9bc8dfa..39c3d52 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -79,7 +79,7 @@ libna_core_la_SOURCES = \
        fma-icontext.c                                                                          \
        fma-icontext-factory.c                                                          \
        fma-iduplicable.c                                                                       \
-       na-iexporter.c                                                                          \
+       fma-iexporter.c                                                                         \
        na-ifactory-object.c                                                            \
        na-ifactory-provider.c                                                          \
        na-iimporter.c                                                                          \
diff --git a/src/core/na-iexporter.c b/src/core/fma-iexporter.c
similarity index 73%
rename from src/core/na-iexporter.c
rename to src/core/fma-iexporter.c
index a25d5bd..3af7db8 100644
--- a/src/core/na-iexporter.c
+++ b/src/core/fma-iexporter.c
@@ -31,29 +31,29 @@
 #include <config.h>
 #endif
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 
 /* private interface data
  */
-struct _NAIExporterInterfacePrivate {
+struct _FMAIExporterInterfacePrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 static guint st_initializations = 0;   /* interface initialization count */
 
 static GType register_type( void );
-static void  interface_base_init( NAIExporterInterface *klass );
-static void  interface_base_finalize( NAIExporterInterface *klass );
+static void  interface_base_init( FMAIExporterInterface *klass );
+static void  interface_base_finalize( FMAIExporterInterface *klass );
 
-static guint iexporter_get_version( const NAIExporter *instance );
+static guint iexporter_get_version( const FMAIExporter *instance );
 
 /**
- * na_iexporter_get_type:
+ * fma_iexporter_get_type:
  *
  * Returns: the #GType type of this interface.
  */
 GType
-na_iexporter_get_type( void )
+fma_iexporter_get_type( void )
 {
        static GType type = 0;
 
@@ -65,18 +65,18 @@ na_iexporter_get_type( void )
 }
 
 /*
- * na_iexporter_register_type:
+ * fma_iexporter_register_type:
  *
  * Registers this interface.
  */
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_iexporter_register_type";
+       static const gchar *thisfn = "fma_iexporter_register_type";
        GType type;
 
        static const GTypeInfo info = {
-               sizeof( NAIExporterInterface ),
+               sizeof( FMAIExporterInterface ),
                ( GBaseInitFunc ) interface_base_init,
                ( GBaseFinalizeFunc ) interface_base_finalize,
                NULL,
@@ -89,7 +89,7 @@ register_type( void )
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( G_TYPE_INTERFACE, "NAIExporter", &info, 0 );
+       type = g_type_register_static( G_TYPE_INTERFACE, "FMAIExporter", &info, 0 );
 
        g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
 
@@ -97,15 +97,15 @@ register_type( void )
 }
 
 static void
-interface_base_init( NAIExporterInterface *klass )
+interface_base_init( FMAIExporterInterface *klass )
 {
-       static const gchar *thisfn = "na_iexporter_interface_base_init";
+       static const gchar *thisfn = "fma_iexporter_interface_base_init";
 
        if( !st_initializations ){
 
                g_debug( "%s: klass%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
-               klass->private = g_new0( NAIExporterInterfacePrivate, 1 );
+               klass->private = g_new0( FMAIExporterInterfacePrivate, 1 );
 
                klass->get_version = iexporter_get_version;
                klass->get_name = NULL;
@@ -118,9 +118,9 @@ interface_base_init( NAIExporterInterface *klass )
 }
 
 static void
-interface_base_finalize( NAIExporterInterface *klass )
+interface_base_finalize( FMAIExporterInterface *klass )
 {
-       static const gchar *thisfn = "na_iexporter_interface_base_finalize";
+       static const gchar *thisfn = "fma_iexporter_interface_base_finalize";
 
        st_initializations -= 1;
 
@@ -133,7 +133,7 @@ interface_base_finalize( NAIExporterInterface *klass )
 }
 
 static guint
-iexporter_get_version( const NAIExporter *instance )
+iexporter_get_version( const FMAIExporter *instance )
 {
        return( 1 );
 }
diff --git a/src/core/na-export-format.h b/src/core/na-export-format.h
index 9a56580..2ac35e7 100644
--- a/src/core/na-export-format.h
+++ b/src/core/na-export-format.h
@@ -35,7 +35,7 @@
  * @include: core/na-export-format.h
  */
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 
 G_BEGIN_DECLS
 
@@ -64,9 +64,9 @@ typedef struct {
 
 GType           na_export_format_get_type    ( void );
 
-NAExportFormat *na_export_format_new         ( const NAIExporterFormatv2 *exporter_format );
+NAExportFormat *na_export_format_new         ( const FMAIExporterFormatv2 *exporter_format );
 
-NAIExporter    *na_export_format_get_provider( const NAExportFormat *format );
+FMAIExporter    *na_export_format_get_provider( const NAExportFormat *format );
 
 G_END_DECLS
 
diff --git a/src/core/na-pivot.h b/src/core/na-pivot.h
index 0cae592..3134146 100644
--- a/src/core/na-pivot.h
+++ b/src/core/na-pivot.h
@@ -138,7 +138,7 @@ NAPivot      *na_pivot_new ( void );
 void          na_pivot_dump( const NAPivot *pivot );
 
 /* Management of the plugins which claim to implement a FileManager-Actions interface.
- * As of 2.30, these may be NAIIOProvider, NAIImporter or NAIExporter
+ * As of 2.30, these may be NAIIOProvider, NAIImporter or FMAIExporter
  */
 GList        *na_pivot_get_providers ( const NAPivot *pivot, GType type );
 void          na_pivot_free_providers( GList *providers );
diff --git a/src/io-desktop/nadp-desktop-provider.c b/src/io-desktop/nadp-desktop-provider.c
index 514d634..0b9ffe6 100644
--- a/src/io-desktop/nadp-desktop-provider.c
+++ b/src/io-desktop/nadp-desktop-provider.c
@@ -70,11 +70,11 @@ static guint  ifactory_provider_get_version( const NAIFactoryProvider *reader );
 static void   iimporter_iface_init( NAIImporterInterface *iface );
 static guint  iimporter_get_version( const NAIImporter *importer );
 
-static void   iexporter_iface_init( NAIExporterInterface *iface );
-static guint  iexporter_get_version( const NAIExporter *exporter );
-static gchar *iexporter_get_name( const NAIExporter *exporter );
-static void  *iexporter_get_formats( const NAIExporter *exporter );
-static void   iexporter_free_formats( const NAIExporter *exporter, GList *format_list );
+static void   iexporter_iface_init( FMAIExporterInterface *iface );
+static guint  iexporter_get_version( const FMAIExporter *exporter );
+static gchar *iexporter_get_name( const FMAIExporter *exporter );
+static void  *iexporter_get_formats( const FMAIExporter *exporter );
+static void   iexporter_free_formats( const FMAIExporter *exporter, GList *format_list );
 
 static void   on_monitor_timeout( NadpDesktopProvider *provider );
 
@@ -135,7 +135,7 @@ nadp_desktop_provider_register_type( GTypeModule *module )
 
        g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
 
-       g_type_module_add_interface( module, st_module_type, NA_TYPE_IEXPORTER, &iexporter_iface_info );
+       g_type_module_add_interface( module, st_module_type, FMA_TYPE_IEXPORTER, &iexporter_iface_info );
 }
 
 static void
@@ -299,7 +299,7 @@ iimporter_get_version( const NAIImporter *importer )
 }
 
 static void
-iexporter_iface_init( NAIExporterInterface *iface )
+iexporter_iface_init( FMAIExporterInterface *iface )
 {
        static const gchar *thisfn = "nadp_desktop_iexporter_iface_init";
 
@@ -314,25 +314,25 @@ iexporter_iface_init( NAIExporterInterface *iface )
 }
 
 static guint
-iexporter_get_version( const NAIExporter *exporter )
+iexporter_get_version( const FMAIExporter *exporter )
 {
        return( 2 );
 }
 
 static gchar *
-iexporter_get_name( const NAIExporter *exporter )
+iexporter_get_name( const FMAIExporter *exporter )
 {
        return( g_strdup( "NA Desktop Exporter" ));
 }
 
 static void *
-iexporter_get_formats( const NAIExporter *exporter )
+iexporter_get_formats( const FMAIExporter *exporter )
 {
        return(( void * ) nadp_formats_get_formats( exporter ));
 }
 
 static void
-iexporter_free_formats( const NAIExporter *exporter, GList *format_list )
+iexporter_free_formats( const FMAIExporter *exporter, GList *format_list )
 {
        nadp_formats_free_formats( format_list );
 }
diff --git a/src/io-desktop/nadp-formats.h b/src/io-desktop/nadp-formats.h
index 89681eb..484040e 100644
--- a/src/io-desktop/nadp-formats.h
+++ b/src/io-desktop/nadp-formats.h
@@ -32,13 +32,13 @@
 
 #include <glib.h>
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 
 G_BEGIN_DECLS
 
 #define NADP_FORMAT_DESKTOP_V1                 "Desktop1"
 
-GList *nadp_formats_get_formats ( const NAIExporter *exporter );
+GList *nadp_formats_get_formats ( const FMAIExporter *exporter );
 void   nadp_formats_free_formats( GList *formats );
 
 G_END_DECLS
diff --git a/src/io-desktop/nadp-writer.h b/src/io-desktop/nadp-writer.h
index 25de910..714a90e 100644
--- a/src/io-desktop/nadp-writer.h
+++ b/src/io-desktop/nadp-writer.h
@@ -31,7 +31,7 @@
 #define __NADP_WRITER_H__
 
 #include <api/na-iio-provider.h>
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 #include <api/na-ifactory-provider.h>
 
 G_BEGIN_DECLS
@@ -43,8 +43,8 @@ guint    nadp_iio_provider_write_item          ( const NAIIOProvider *provider,
 guint    nadp_iio_provider_delete_item         ( const NAIIOProvider *provider, const NAObjectItem *item, 
GSList **messages );
 guint    nadp_iio_provider_duplicate_data      ( const NAIIOProvider *provider, NAObjectItem *dest, const 
NAObjectItem *source, GSList **messages );
 
-guint    nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 
*parms );
-guint    nadp_writer_iexporter_export_to_file  ( const NAIExporter *instance, NAIExporterFileParmsv2 *parms 
);
+guint    nadp_writer_iexporter_export_to_buffer( const FMAIExporter *instance, FMAIExporterBufferParmsv2 
*parms );
+guint    nadp_writer_iexporter_export_to_file  ( const FMAIExporter *instance, FMAIExporterFileParmsv2 
*parms );
 
 guint    nadp_writer_ifactory_provider_write_start(
                                const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject 
*object,
diff --git a/src/io-xml/naxml-formats.h b/src/io-xml/naxml-formats.h
index 0ca18a0..e0f08e5 100644
--- a/src/io-xml/naxml-formats.h
+++ b/src/io-xml/naxml-formats.h
@@ -32,7 +32,7 @@
 
 #include <glib.h>
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 
 G_BEGIN_DECLS
 
@@ -40,7 +40,7 @@ G_BEGIN_DECLS
 #define NAXML_FORMAT_GCONF_SCHEMA_V2                   "GConfSchemaV2"
 #define NAXML_FORMAT_GCONF_ENTRY                               "GConfEntry"
 
-GList *naxml_formats_get_formats ( const NAIExporter *exporter );
+GList *naxml_formats_get_formats ( const FMAIExporter *exporter );
 void   naxml_formats_free_formats( GList *format_list );
 
 G_END_DECLS
diff --git a/src/io-xml/naxml-provider.c b/src/io-xml/naxml-provider.c
index a884a99..68e9129 100644
--- a/src/io-xml/naxml-provider.c
+++ b/src/io-xml/naxml-provider.c
@@ -32,7 +32,7 @@
 #endif
 
 #include <api/na-ifactory-provider.h>
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 #include <api/na-iimporter.h>
 
 #include "naxml-provider.h"
@@ -63,11 +63,11 @@ static void   instance_finalize( GObject *object );
 static void   iimporter_iface_init( NAIImporterInterface *iface );
 static guint  iimporter_get_version( const NAIImporter *importer );
 
-static void   iexporter_iface_init( NAIExporterInterface *iface );
-static guint  iexporter_get_version( const NAIExporter *exporter );
-static gchar *iexporter_get_name( const NAIExporter *exporter );
-static void  *iexporter_get_formats( const NAIExporter *exporter );
-static void   iexporter_free_formats( const NAIExporter *exporter, GList *format_list );
+static void   iexporter_iface_init( FMAIExporterInterface *iface );
+static guint  iexporter_get_version( const FMAIExporter *exporter );
+static gchar *iexporter_get_name( const FMAIExporter *exporter );
+static void  *iexporter_get_formats( const FMAIExporter *exporter );
+static void   iexporter_free_formats( const FMAIExporter *exporter, GList *format_list );
 
 static void   ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
 static guint  ifactory_provider_get_version( const NAIFactoryProvider *factory );
@@ -119,7 +119,7 @@ naxml_provider_register_type( GTypeModule *module )
 
        g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
 
-       g_type_module_add_interface( module, st_module_type, NA_TYPE_IEXPORTER, &iexporter_iface_info );
+       g_type_module_add_interface( module, st_module_type, FMA_TYPE_IEXPORTER, &iexporter_iface_info );
 
        g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER, 
&ifactory_provider_iface_info );
 }
@@ -220,7 +220,7 @@ iimporter_get_version( const NAIImporter *importer )
 }
 
 static void
-iexporter_iface_init( NAIExporterInterface *iface )
+iexporter_iface_init( FMAIExporterInterface *iface )
 {
        static const gchar *thisfn = "naxml_provider_iexporter_iface_init";
 
@@ -235,25 +235,25 @@ iexporter_iface_init( NAIExporterInterface *iface )
 }
 
 static guint
-iexporter_get_version( const NAIExporter *exporter )
+iexporter_get_version( const FMAIExporter *exporter )
 {
        return( 2 );
 }
 
 static gchar *
-iexporter_get_name( const NAIExporter *exporter )
+iexporter_get_name( const FMAIExporter *exporter )
 {
        return( g_strdup( "NAXML Exporter" ));
 }
 
 static void *
-iexporter_get_formats( const NAIExporter *exporter )
+iexporter_get_formats( const FMAIExporter *exporter )
 {
        return(( void * ) naxml_formats_get_formats( exporter ));
 }
 
 static void
-iexporter_free_formats( const NAIExporter *exporter, GList *format_list )
+iexporter_free_formats( const FMAIExporter *exporter, GList *format_list )
 {
        naxml_formats_free_formats( format_list );
 }
diff --git a/src/io-xml/naxml-writer.h b/src/io-xml/naxml-writer.h
index b50a9bd..652cce2 100644
--- a/src/io-xml/naxml-writer.h
+++ b/src/io-xml/naxml-writer.h
@@ -39,7 +39,7 @@
  */
 
 #include <api/fma-data-boxed.h>
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 #include <api/na-ifactory-provider.h>
 
 G_BEGIN_DECLS
@@ -71,8 +71,8 @@ typedef struct {
 
 GType  naxml_writer_get_type( void );
 
-guint  naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms );
-guint  naxml_writer_export_to_file  ( const NAIExporter *instance, NAIExporterFileParmsv2 *parms );
+guint  naxml_writer_export_to_buffer( const FMAIExporter *instance, FMAIExporterBufferParmsv2 *parms );
+guint  naxml_writer_export_to_file  ( const FMAIExporter *instance, FMAIExporterFileParmsv2 *parms );
 
 guint  naxml_writer_write_start( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, GSList **messages  );
 guint  naxml_writer_write_data ( const NAIFactoryProvider *writer, void *writer_data, const NAIFactoryObject 
*object, const FMADataBoxed *boxed, GSList **messages );
diff --git a/src/utils/nautilus-actions-print.c b/src/utils/nautilus-actions-print.c
index 8f56764..4ed8618 100644
--- a/src/utils/nautilus-actions-print.c
+++ b/src/utils/nautilus-actions-print.c
@@ -87,7 +87,7 @@ main( int argc, char** argv )
        gchar *help;
        gint errors;
        NAObjectItem *item;
-       NAIExporter *exporter;
+       FMAIExporter *exporter;
 
 #if !GLIB_CHECK_VERSION( 2,36, 0 )
        g_type_init();


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/na-export-format.c b/src/core/na-export-format.c
index c012f1e..aaa7e8e 100644
--- a/src/core/na-export-format.c
+++ b/src/core/na-export-format.c
@@ -48,7 +48,7 @@ struct _NAExportFormatPrivate {
        gchar       *label;
        gchar       *description;
        GdkPixbuf   *pixbuf;
-       NAIExporter *provider;
+       FMAIExporter *provider;
 };
 
 static GObjectClass *st_parent_class = NULL;
@@ -313,12 +313,12 @@ instance_finalize( GObject *object )
 
 /*
  * na_export_format_new:
  * @exporter_format: a #NAIExporterFormatv2 which describes an export format.
  *
  * Returns: a newly allocated #NAExportFormat object.
  */
 NAExportFormat *
-na_export_format_new( const NAIExporterFormatv2 *exporter_format )
+na_export_format_new( const FMAIExporterFormatv2 *exporter_format )
 {
        NAExportFormat *format;
 
@@ -337,15 +337,15 @@ na_export_format_new( const NAIExporterFormatv2 *exporter_format )
  * na_export_format_get_provider:
  * @format: this #NAExportFormat object.
  *
  * Returns: a pointer to the #NAIExporter which provides this format.
  *
  * The pointer is owned by NAEportFormat class, and should not be released
  * by the caller.
  */
-NAIExporter *
+FMAIExporter *
 na_export_format_get_provider( const NAExportFormat *format )
 {
-       NAIExporter *exporter;
+       FMAIExporter *exporter;
 
        g_return_val_if_fail( NA_IS_EXPORT_FORMAT( format ), NULL );
 
@@ -313,12 +313,12 @@ instance_finalize( GObject *object )
 /*
  * na_export_format_new:
- * @exporter_format: a #NAIExporterFormatv2 which describes an export format.
+ * @exporter_format: a #FMAIExporterFormatv2 which describes an export format.
  *
  * Returns: a newly allocated #NAExportFormat object.
@@ -337,15 +337,15 @@ na_export_format_new( const NAIExporterFormatv2 *exporter_format )
  * @format: this #NAExportFormat object.
  *
- * Returns: a pointer to the #NAIExporter which provides this format.
+ * Returns: a pointer to the #FMAIExporter which provides this format.
  *
  * The pointer is owned by NAEportFormat class, and should not be released
diff --git a/src/core/na-exporter.c b/src/core/na-exporter.c
index 7594160..9049182 100644
--- a/src/core/na-exporter.c
+++ b/src/core/na-exporter.c
@@ -56,12 +56,12 @@ static NAExporterFormatStr st_format_ask = {
                "export-format-ask.png"
 };
 
 /* i18n: NAIExporter is an interface name, do not even try to translate */
 #define NO_IMPLEMENTATION_MSG                  N_( "No NAIExporter implementation found for '%s' format." )
 
-static GList *exporter_get_formats( const NAIExporter *exporter );
-static void   exporter_free_formats( const NAIExporter *exporter, GList * str_list );
-static gchar *exporter_get_name( const NAIExporter *exporter );
+static GList *exporter_get_formats( const FMAIExporter *exporter );
+static void   exporter_free_formats( const FMAIExporter *exporter, GList * str_list );
+static gchar *exporter_get_name( const FMAIExporter *exporter );
 static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
 
 /*
@@ -70,7 +70,7 @@ static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
  *
  * Returns: a list of #NAExportFormat objects, each of them addressing an
  * available export format, i.e. a format provided by a module which
  * implement the #NAIExporter interface.
  *
  * The returned list should later be na_exporter_free_formats() by the caller.
  */
@@ -85,17 +85,17 @@ na_exporter_get_formats( const NAPivot *pivot )
        g_return_val_if_fail( NA_IS_PIVOT( pivot ), NULL );
 
        formats = NULL;
-       iexporters = na_pivot_get_providers( pivot, NA_TYPE_IEXPORTER );
+       iexporters = na_pivot_get_providers( pivot, FMA_TYPE_IEXPORTER );
 
        for( imod = iexporters ; imod ; imod = imod->next ){
-               str_list = exporter_get_formats( NA_IEXPORTER( imod->data ));
+               str_list = exporter_get_formats( FMA_IEXPORTER( imod->data ));
 
                for( is = str_list ; is ; is = is->next ){
-                       format = na_export_format_new(( NAIExporterFormatv2 * ) is->data );
+                       format = na_export_format_new(( FMAIExporterFormatv2 * ) is->data );
                        formats = g_list_prepend( formats, format );
                }
 
-               exporter_free_formats( NA_IEXPORTER( imod->data ), str_list );
+               exporter_free_formats( FMA_IEXPORTER( imod->data ), str_list );
        }
 
        na_pivot_free_providers( iexporters );
@@ -104,13 +104,13 @@ na_exporter_get_formats( const NAPivot *pivot )
 }
 
 /*
  * Returns a GList of NAIExporterFormatv2 structures which describes
  * the export formats provided by the exporter
  * If the provider only implements the v1 interface, we dynamically
  * allocate a new structure and convert the v1 to the v2.
  */
 static GList *
-exporter_get_formats( const NAIExporter *exporter )
+exporter_get_formats( const FMAIExporter *exporter )
 {
        GList *str_list;
        guint version;
@@ -118,19 +118,19 @@ exporter_get_formats( const NAIExporter *exporter )
        str_list = NULL;
 
        version = 1;
-       if( NA_IEXPORTER_GET_INTERFACE( exporter )->get_version ){
-               version = NA_IEXPORTER_GET_INTERFACE( exporter )->get_version( exporter );
+       if( FMA_IEXPORTER_GET_INTERFACE( exporter )->get_version ){
+               version = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_version( exporter );
        }
 
-       if( NA_IEXPORTER_GET_INTERFACE( exporter )->get_formats ){
+       if( FMA_IEXPORTER_GET_INTERFACE( exporter )->get_formats ){
                if( version == 1 ){
 #ifdef NA_ENABLE_DEPRECATED
-                       const NAIExporterFormat *strv1;
-                       strv1 = NA_IEXPORTER_GET_INTERFACE( exporter )->get_formats( exporter );
+                       const FMAIExporterFormat *strv1;
+                       strv1 = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_formats( exporter );
                        while( strv1->format ){
-                               NAIExporterFormatv2 *strv2 = g_new0( NAIExporterFormatv2, 1 );
+                               FMAIExporterFormatv2 *strv2 = g_new0( FMAIExporterFormatv2, 1 );
                                strv2->version = 2;
-                               strv2->provider = ( NAIExporter * ) exporter;
+                               strv2->provider = ( FMAIExporter * ) exporter;
                                strv2->format = strv1->format;
                                strv2->label = strv1->label;
                                strv2->description = strv1->description;
@@ -142,7 +142,7 @@ exporter_get_formats( const NAIExporter *exporter )
                        ;
 #endif
                } else {
-                       str_list = NA_IEXPORTER_GET_INTERFACE( exporter )->get_formats( exporter );
+                       str_list = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_formats( exporter );
                }
        }
 
@@ -153,13 +153,13 @@ exporter_get_formats( const NAIExporter *exporter )
  * Free the list returned by exporter_get_formats() for this provider
  */
 static void
-exporter_free_formats( const NAIExporter *exporter, GList *str_list )
+exporter_free_formats( const FMAIExporter *exporter, GList *str_list )
 {
        guint version;
 
        version = 1;
-       if( NA_IEXPORTER_GET_INTERFACE( exporter )->get_version ){
-               version = NA_IEXPORTER_GET_INTERFACE( exporter )->get_version( exporter );
+       if( FMA_IEXPORTER_GET_INTERFACE( exporter )->get_version ){
+               version = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_version( exporter );
        }
 
        if( version == 1 ){
@@ -167,8 +167,8 @@ exporter_free_formats( const NAIExporter *exporter, GList *str_list )
                g_list_free( str_list );
 
        } else {
-               g_return_if_fail( NA_IEXPORTER_GET_INTERFACE( exporter )->free_formats );
-               NA_IEXPORTER_GET_INTERFACE( exporter )->free_formats( exporter, str_list );
+               g_return_if_fail( FMA_IEXPORTER_GET_INTERFACE( exporter )->free_formats );
+               FMA_IEXPORTER_GET_INTERFACE( exporter )->free_formats( exporter, str_list );
        }
 }
 
@@ -201,7 +201,7 @@ NAIOption *
 na_exporter_get_ask_option( void )
 {
        static const gchar *thisfn = "na_exporter_get_ask_option";
-       NAIExporterFormatv2 *str;
+       FMAIExporterFormatv2 *str;
        gint width, height;
        gchar *fname;
        NAExportFormat *format;
@@ -210,7 +210,7 @@ na_exporter_get_ask_option( void )
                width = height = 48;
        }
 
-       str = g_new0( NAIExporterFormatv2, 1 );
+       str = g_new0( FMAIExporterFormatv2, 1 );
        str->version = 2;
        str->provider = NULL;
        str->format = g_strdup( st_format_ask.format );
@@ -264,8 +264,8 @@ na_exporter_to_buffer( const NAPivot *pivot,
 {
        static const gchar *thisfn = "na_exporter_to_buffer";
        gchar *buffer;
-       NAIExporterBufferParmsv2 parms;
-       NAIExporter *exporter;
+       FMAIExporterBufferParmsv2 parms;
+       FMAIExporter *exporter;
        gchar *name;
        gchar *msg;
 
@@ -291,8 +291,8 @@ na_exporter_to_buffer( const NAPivot *pivot,
                parms.buffer = NULL;
                parms.messages = messages ? *messages : NULL;
 
-               if( NA_IEXPORTER_GET_INTERFACE( exporter )->to_buffer ){
-                       NA_IEXPORTER_GET_INTERFACE( exporter )->to_buffer( exporter, &parms );
+               if( FMA_IEXPORTER_GET_INTERFACE( exporter )->to_buffer ){
+                       FMA_IEXPORTER_GET_INTERFACE( exporter )->to_buffer( exporter, &parms );
 
                        if( parms.buffer ){
                                buffer = parms.buffer;
@@ -300,8 +300,8 @@ na_exporter_to_buffer( const NAPivot *pivot,
 
                } else {
                        name = exporter_get_name( exporter );
-                       /* i18n: NAIExporter is an interface name, do not even try to translate */
-                       msg = g_strdup_printf( _( "%s NAIExporter doesn't implement 'to_buffer' interface." 
), name );
+                       /* i18n: FMAIExporter is an interface name, do not even try to translate */
+                       msg = g_strdup_printf( _( "%s FMAIExporter doesn't implement 'to_buffer' interface." 
), name );
                        *messages = g_slist_append( *messages, msg );
                        g_free( name );
                }
@@ -336,8 +336,8 @@ na_exporter_to_file( const NAPivot *pivot,
 {
        static const gchar *thisfn = "na_exporter_to_file";
        gchar *export_uri;
-       NAIExporterFileParmsv2 parms;
-       NAIExporter *exporter;
+       FMAIExporterFileParmsv2 parms;
+       FMAIExporter *exporter;
        gchar *msg;
        gchar *name;
 
@@ -364,8 +364,8 @@ na_exporter_to_file( const NAPivot *pivot,
                parms.basename = NULL;
                parms.messages = messages ? *messages : NULL;
 
-               if( NA_IEXPORTER_GET_INTERFACE( exporter )->to_file ){
-                       NA_IEXPORTER_GET_INTERFACE( exporter )->to_file( exporter, &parms );
+               if( FMA_IEXPORTER_GET_INTERFACE( exporter )->to_file ){
+                       FMA_IEXPORTER_GET_INTERFACE( exporter )->to_file( exporter, &parms );
 
                        if( parms.basename ){
                                export_uri = g_strdup_printf( "%s%s%s", folder_uri, G_DIR_SEPARATOR_S, 
parms.basename );
@@ -373,8 +373,8 @@ na_exporter_to_file( const NAPivot *pivot,
 
                } else {
                        name = exporter_get_name( exporter );
-                       /* i18n: NAIExporter is an interface name, do not even try to translate */
-                       msg = g_strdup_printf( _( "%s NAIExporter doesn't implement 'to_file' interface." ), 
name );
+                       /* i18n: FMAIExporter is an interface name, do not even try to translate */
+                       msg = g_strdup_printf( _( "%s FMAIExporter doesn't implement 'to_file' interface." ), 
name );
                        *messages = g_slist_append( *messages, msg );
                        g_free( name );
                }
@@ -390,14 +390,14 @@ na_exporter_to_file( const NAPivot *pivot,
 }
 
 static gchar *
-exporter_get_name( const NAIExporter *exporter )
+exporter_get_name( const FMAIExporter *exporter )
 {
        gchar *name;
 
        name = NULL;
 
-       if( NA_IEXPORTER_GET_INTERFACE( exporter )->get_name ){
-               name = NA_IEXPORTER_GET_INTERFACE( exporter )->get_name( exporter );
+       if( FMA_IEXPORTER_GET_INTERFACE( exporter )->get_name ){
+               name = FMA_IEXPORTER_GET_INTERFACE( exporter )->get_name( exporter );
        }
 
        return( name );
@@ -408,14 +408,14 @@ exporter_get_name( const NAIExporter *exporter )
  * @pivot: the #NAPivot instance.
  * @format: the string identifier of the searched format.
  *
  * Returns: the #NAIExporter instance which provides the @format export
  * format. The returned instance is owned by @pivot, and should not be
  * released by the caller.
  */
-NAIExporter *
+FMAIExporter *
 na_exporter_find_for_format( const NAPivot *pivot, const gchar *format )
 {
-       NAIExporter *exporter;
+       FMAIExporter *exporter;
        GList *formats, *ifmt;
        gchar *id;
        NAExportFormat *export_format;
@@ -56,12 +56,12 @@ static NAExporterFormatStr st_format_ask = {
 };
 
-/* i18n: NAIExporter is an interface name, do not even try to translate */
-#define NO_IMPLEMENTATION_MSG                  N_( "No NAIExporter implementation found for '%s' format." )
+/* i18n: FMAIExporter is an interface name, do not even try to translate */
+#define NO_IMPLEMENTATION_MSG                  N_( "No FMAIExporter implementation found for '%s' format." )
 
@@ -70,7 +70,7 @@ static void   on_pixbuf_finalized( gpointer user_data, GObject *pixbuf );
  * Returns: a list of #NAExportFormat objects, each of them addressing an
  * available export format, i.e. a format provided by a module which
- * implement the #NAIExporter interface.
+ * implement the #FMAIExporter interface.
  *
  * The returned list should later be na_exporter_free_formats() by the caller.
@@ -104,13 +104,13 @@ na_exporter_get_formats( const NAPivot *pivot )
 
 /*
- * Returns a GList of NAIExporterFormatv2 structures which describes
+ * Returns a GList of FMAIExporterFormatv2 structures which describes
  * the export formats provided by the exporter
  * If the provider only implements the v1 interface, we dynamically
@@ -408,14 +408,14 @@ exporter_get_name( const NAIExporter *exporter )
  * @format: the string identifier of the searched format.
  *
- * Returns: the #NAIExporter instance which provides the @format export
+ * Returns: the #FMAIExporter instance which provides the @format export
  * format. The returned instance is owned by @pivot, and should not be
  * released by the caller.
diff --git a/src/core/na-exporter.h b/src/core/na-exporter.h
index 460944f..77b7a8a 100644
--- a/src/core/na-exporter.h
+++ b/src/core/na-exporter.h
@@ -30,12 +30,12 @@
 #ifndef __CORE_NA_EXPORTER_H__
 #define __CORE_NA_EXPORTER_H__
 
 /* @title: NAIExporter
  * @short_description: The #NAIExporter Internal Functions
  * @include: core/na-exporter.h
  */
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 #include <api/na-object-api.h>
 
 #include "na-ioption.h"
@@ -61,7 +61,7 @@ gchar       *na_exporter_to_file        ( const NAPivot *pivot,
                                           const gchar *format,
                                           GSList **messages );
 
-NAIExporter *na_exporter_find_for_format( const NAPivot *pivot,
+FMAIExporter *na_exporter_find_for_format( const NAPivot *pivot,
                                                  const gchar *format );
 
 G_END_DECLS
@@ -30,12 +30,12 @@
 #define __CORE_NA_EXPORTER_H__
 
-/* @title: NAIExporter
- * @short_description: The #NAIExporter Internal Functions
+/* @title: FMAIExporter
+ * @short_description: The #FMAIExporter Internal Functions
  * @include: core/na-exporter.h
  */
diff --git a/src/io-desktop/nadp-formats.c b/src/io-desktop/nadp-formats.c
index 94736fd..ca8c3c0 100644
--- a/src/io-desktop/nadp-formats.c
+++ b/src/io-desktop/nadp-formats.c
@@ -35,7 +35,7 @@
 #include <gtk/gtk.h>
 #include <libintl.h>
 
-#include <api/na-iexporter.h>
+#include <api/fma-iexporter.h>
 
 #include "nadp-formats.h"
 
@@ -70,27 +70,27 @@ static NadpExportFormat nadp_formats[] = {
 };
 
 #if 0
-static void on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf );
+static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf );
 #endif
 
 /**
  * nadp_formats_get_formats:
- * @exporter: this #NAIExporter provider.
+ * @exporter: this #FMAIExporter provider.
  *
  * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
  *
  * This list should be nadp_formats_free_formats() by the caller.
  *
  * Since: 3.2
  */
 GList *
-nadp_formats_get_formats( const NAIExporter* exporter )
+nadp_formats_get_formats( const FMAIExporter* exporter )
 {
 #if 0
        static const gchar *thisfn = "nadp_formats_get_formats";
 #endif
        GList *str_list;
-       NAIExporterFormatv2 *str;
+       FMAIExporterFormatv2 *str;
        guint i;
        gint width, height;
        gchar *fname;
@@ -102,9 +102,9 @@ nadp_formats_get_formats( const NAIExporter* exporter )
        }
 
        for( i = 0 ; nadp_formats[i].format ; ++i ){
-               str = g_new0( NAIExporterFormatv2, 1 );
+               str = g_new0( FMAIExporterFormatv2, 1 );
                str->version = 2;
-               str->provider = NA_IEXPORTER( exporter );
+               str->provider = FMA_IEXPORTER( exporter );
                str->format = g_strdup( nadp_formats[i].format );
                str->label = g_strdup( gettext( nadp_formats[i].label ));
                str->description = g_strdup( gettext( nadp_formats[i].description ));
@@ -132,7 +132,7 @@ nadp_formats_get_formats( const NAIExporter* exporter )
 
 #if 0
 static void
-on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf )
+on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 {
        g_debug( "nadp_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * ) 
pixbuf );
 }
@@ -142,7 +142,7 @@ on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf )
  * nadp_formats_free_formats:
  * @formats: a #GList to be freed.
  *
  * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
  *
  * This list should be nadp_format_free_formats() by the caller.
  *
@@ -152,10 +152,10 @@ void
 nadp_formats_free_formats( GList *formats )
 {
        GList *is;
-       NAIExporterFormatv2 *str;
+       FMAIExporterFormatv2 *str;
 
        for( is = formats ; is ; is = is->next ){
-               str = ( NAIExporterFormatv2 * ) is->data;
+               str = ( FMAIExporterFormatv2 * ) is->data;
                g_free( str->format );
                g_free( str->label );
                g_free( str->description );
@@ -70,27 +70,27 @@ static NadpExportFormat nadp_formats[] = {
  *
- * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
+ * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
  * This list should be nadp_formats_free_formats() by the caller.
@@ -142,7 +142,7 @@ on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf )
  * @formats: a #GList to be freed.
  *
- * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
+ * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
  * This list should be nadp_format_free_formats() by the caller.
diff --git a/src/io-desktop/nadp-writer.c b/src/io-desktop/nadp-writer.c
index 9117e41..8a86f49 100644
--- a/src/io-desktop/nadp-writer.c
+++ b/src/io-desktop/nadp-writer.c
@@ -346,13 +346,13 @@ nadp_iio_provider_duplicate_data( const NAIIOProvider *provider, NAObjectItem *d
 
 /**
  * nadp_writer_iexporter_export_to_buffer:
  * @instance: this #NAIExporter instance.
  * @parms: a #NAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
  */
 guint
-nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms )
+nadp_writer_iexporter_export_to_buffer( const FMAIExporter *instance, FMAIExporterBufferParmsv2 *parms )
 {
        static const gchar *thisfn = "nadp_writer_iexporter_export_to_buffer";
        guint code, write_code;
@@ -363,17 +363,17 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
 
        parms->buffer = NULL;
-       code = NA_IEXPORTER_CODE_OK;
+       code = FMA_IEXPORTER_CODE_OK;
 
        if( !parms->exported || !NA_IS_OBJECT_ITEM( parms->exported )){
-               code = NA_IEXPORTER_CODE_INVALID_ITEM;
+               code = FMA_IEXPORTER_CODE_INVALID_ITEM;
        }
 
-       if( code == NA_IEXPORTER_CODE_OK ){
+       if( code == FMA_IEXPORTER_CODE_OK ){
 
 #ifdef NA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
-                       fmt = find_export_format_fn_from_quark((( NAIExporterBufferParms * ) parms )->format 
);
+                       fmt = find_export_format_fn_from_quark((( FMAIExporterBufferParms * ) parms )->format 
);
                } else {
                        fmt = find_export_format_fn( parms->format );
                }
@@ -382,14 +382,14 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
 #endif
 
                if( !fmt ){
-                       code = NA_IEXPORTER_CODE_INVALID_FORMAT;
+                       code = FMA_IEXPORTER_CODE_INVALID_FORMAT;
 
                } else {
                        ndf = nadp_desktop_file_new();
                        write_code = na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( instance ), ndf, 
NA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
 
                        if( write_code != NA_IIO_PROVIDER_CODE_OK ){
-                               code = NA_IEXPORTER_CODE_ERROR;
+                               code = FMA_IEXPORTER_CODE_ERROR;
 
                        } else {
                                key_file = nadp_desktop_file_get_key_file( ndf );
@@ -406,13 +406,13 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
 
 /**
  * nadp_writer_iexporter_export_to_file:
  * @instance: this #NAIExporter instance.
  * @parms: a #NAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.
  */
 guint
-nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2 *parms )
+nadp_writer_iexporter_export_to_file( const FMAIExporter *instance, FMAIExporterFileParmsv2 *parms )
 {
        static const gchar *thisfn = "nadp_writer_iexporter_export_to_file";
        guint code, write_code;
@@ -423,17 +423,17 @@ nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFi
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
 
        parms->basename = NULL;
-       code = NA_IEXPORTER_CODE_OK;
+       code = FMA_IEXPORTER_CODE_OK;
 
        if( !parms->exported || !NA_IS_OBJECT_ITEM( parms->exported )){
-               code = NA_IEXPORTER_CODE_INVALID_ITEM;
+               code = FMA_IEXPORTER_CODE_INVALID_ITEM;
        }
 
-       if( code == NA_IEXPORTER_CODE_OK ){
+       if( code == FMA_IEXPORTER_CODE_OK ){
 
 #ifdef NA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
-                       fmt = find_export_format_fn_from_quark((( NAIExporterFileParms * ) parms )->format );
+                       fmt = find_export_format_fn_from_quark((( FMAIExporterFileParms * ) parms )->format );
                } else {
                        fmt = find_export_format_fn( parms->format );
                }
@@ -442,7 +442,7 @@ nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFi
 #endif
 
                if( !fmt ){
-                       code = NA_IEXPORTER_CODE_INVALID_FORMAT;
+                       code = FMA_IEXPORTER_CODE_INVALID_FORMAT;
 
                } else {
                        id = na_object_get_id( parms->exported );
@@ -457,10 +457,10 @@ nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFi
                        write_code = na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( instance ), ndf, 
NA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
 
                        if( write_code != NA_IIO_PROVIDER_CODE_OK ){
-                               code = NA_IEXPORTER_CODE_ERROR;
+                               code = FMA_IEXPORTER_CODE_ERROR;
 
                        } else if( !nadp_desktop_file_write( ndf )){
-                               code = NA_IEXPORTER_CODE_UNABLE_TO_WRITE;
+                               code = FMA_IEXPORTER_CODE_UNABLE_TO_WRITE;
                        }
 
                        g_free( dest_path );
@@ -346,13 +346,13 @@ nadp_iio_provider_duplicate_data( const NAIIOProvider *provider, NAObjectItem *d
 /**
  * nadp_writer_iexporter_export_to_buffer:
- * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterBufferParmsv2 structure.
+ * @instance: this #FMAIExporter instance.
+ * @parms: a #FMAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
@@ -406,13 +406,13 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
 /**
  * nadp_writer_iexporter_export_to_file:
- * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterFileParmsv2 structure.
+ * @instance: this #FMAIExporter instance.
+ * @parms: a #FMAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.
diff --git a/src/io-xml/naxml-formats.c b/src/io-xml/naxml-formats.c
index 367edd4..0546cf0 100644
--- a/src/io-xml/naxml-formats.c
+++ b/src/io-xml/naxml-formats.c
@@ -94,27 +94,27 @@ static NaxmlExportFormat naxml_formats[] = {
 };
 
 #if 0
-static void on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf );
+static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf );
 #endif
 
 /**
  * naxml_formats_get_formats:
- * @exporter: this #NAIExporter provider.
+ * @exporter: this #FMAIExporter provider.
  *
  * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
  *
  * This list should be naxml_formats_free_formats() by the caller.
  *
  * Since: 3.2
  */
 GList *
-naxml_formats_get_formats( const NAIExporter* exporter )
+naxml_formats_get_formats( const FMAIExporter* exporter )
 {
 #if 0
        static const gchar *thisfn = "naxml_formats_get_formats";
 #endif
        GList *str_list;
-       NAIExporterFormatv2 *str;
+       FMAIExporterFormatv2 *str;
        guint i;
        gint width, height;
        gchar *fname;
@@ -126,9 +126,9 @@ naxml_formats_get_formats( const NAIExporter* exporter )
        }
 
        for( i = 0 ; naxml_formats[i].format ; ++i ){
-               str = g_new0( NAIExporterFormatv2, 1 );
+               str = g_new0( FMAIExporterFormatv2, 1 );
                str->version = 2;
-               str->provider = NA_IEXPORTER( exporter );
+               str->provider = FMA_IEXPORTER( exporter );
                str->format = g_strdup( naxml_formats[i].format );
                str->label = g_strdup( gettext( naxml_formats[i].label ));
                str->description = g_strdup( gettext( naxml_formats[i].description ));
@@ -156,7 +156,7 @@ naxml_formats_get_formats( const NAIExporter* exporter )
 
 #if 0
 static void
-on_pixbuf_finalized( const NAIExporter* exporter, GObject *pixbuf )
+on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 {
        g_debug( "naxml_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * ) 
pixbuf );
 }
@@ -174,10 +174,10 @@ void
 naxml_formats_free_formats( GList *formats )
 {
        GList *is;
-       NAIExporterFormatv2 *str;
+       FMAIExporterFormatv2 *str;
 
        for( is = formats ; is ; is = is->next ){
-               str = ( NAIExporterFormatv2 * ) is->data;
+               str = ( FMAIExporterFormatv2 * ) is->data;
                g_free( str->format );
                g_free( str->label );
                g_free( str->description );
@@ -94,27 +94,27 @@ static NaxmlExportFormat naxml_formats[] = {
  *
- * Returns: a #GList of the #NAIExporterFormatv2 supported export formats.
+ * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
  * This list should be naxml_formats_free_formats() by the caller.
diff --git a/src/io-xml/naxml-writer.c b/src/io-xml/naxml-writer.c
index 44a682b..b04eb41 100644
--- a/src/io-xml/naxml-writer.c
+++ b/src/io-xml/naxml-writer.c
@@ -60,7 +60,7 @@ struct _NAXMLWriterClassPrivate {
  */
 struct _NAXMLWriterPrivate {
        gboolean         dispose_has_run;
-       NAIExporter     *provider;
+       FMAIExporter     *provider;
        NAObjectItem    *exported;
        GSList          *messages;
 
@@ -266,13 +266,13 @@ instance_finalize( GObject *object )
 
 /**
  * naxml_writer_export_to_buffer:
  * @instance: this #NAIExporter instance.
  * @parms: a #NAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
  */
 guint
-naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms )
+naxml_writer_export_to_buffer( const FMAIExporter *instance, FMAIExporterBufferParmsv2 *parms )
 {
        static const gchar *thisfn = "naxml_writer_export_to_buffer";
        NAXMLWriter *writer;
@@ -280,21 +280,21 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
 
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
 
-       code = NA_IEXPORTER_CODE_OK;
+       code = FMA_IEXPORTER_CODE_OK;
 
        if( !parms->exported || !NA_IS_OBJECT_ITEM( parms->exported )){
-               code = NA_IEXPORTER_CODE_INVALID_ITEM;
+               code = FMA_IEXPORTER_CODE_INVALID_ITEM;
        }
 
-       if( code == NA_IEXPORTER_CODE_OK ){
+       if( code == FMA_IEXPORTER_CODE_OK ){
                writer = NAXML_WRITER( g_object_new( NAXML_WRITER_TYPE, NULL ));
 
-               writer->private->provider = ( NAIExporter * ) instance;
+               writer->private->provider = ( FMAIExporter * ) instance;
                writer->private->exported = parms->exported;
                writer->private->messages = parms->messages;
 #ifdef NA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
-                       writer->private->fn_str = find_export_format_fn_from_quark((( NAIExporterBufferParms 
* ) parms )->format );
+                       writer->private->fn_str = find_export_format_fn_from_quark((( FMAIExporterBufferParms 
* ) parms )->format );
                } else {
                        writer->private->fn_str = find_export_format_fn( parms->format );
                }
@@ -304,11 +304,11 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
                writer->private->buffer = NULL;
 
                if( !writer->private->fn_str ){
-                       code = NA_IEXPORTER_CODE_INVALID_FORMAT;
+                       code = FMA_IEXPORTER_CODE_INVALID_FORMAT;
 
                } else {
                        code = writer_to_buffer( writer );
-                       if( code == NA_IEXPORTER_CODE_OK ){
+                       if( code == FMA_IEXPORTER_CODE_OK ){
                                parms->buffer = writer->private->buffer;
                        }
                }
@@ -322,13 +322,13 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
 
 /**
  * naxml_writer_export_to_file:
  * @instance: this #NAIExporter instance.
  * @parms: a #NAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.
  */
 guint
-naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2 *parms )
+naxml_writer_export_to_file( const FMAIExporter *instance, FMAIExporterFileParmsv2 *parms )
 {
        static const gchar *thisfn = "naxml_writer_export_to_file";
        NAXMLWriter *writer;
@@ -338,22 +338,22 @@ naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2
 
        g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
 
-       code = NA_IEXPORTER_CODE_OK;
+       code = FMA_IEXPORTER_CODE_OK;
 
        if( !parms->exported || !NA_IS_OBJECT_ITEM( parms->exported )){
-               code = NA_IEXPORTER_CODE_INVALID_ITEM;
+               code = FMA_IEXPORTER_CODE_INVALID_ITEM;
        }
 
-       if( code == NA_IEXPORTER_CODE_OK ){
+       if( code == FMA_IEXPORTER_CODE_OK ){
                writer = NAXML_WRITER( g_object_new( NAXML_WRITER_TYPE, NULL ));
 
-               writer->private->provider = ( NAIExporter * ) instance;
+               writer->private->provider = ( FMAIExporter * ) instance;
                writer->private->exported = parms->exported;
                writer->private->messages = parms->messages;
 #ifdef NA_ENABLE_DEPRECATED
                if( parms->version == 1 ){
-                       writer->private->fn_str = find_export_format_fn_from_quark((( NAIExporterFileParms * 
) parms )->format );
-                       format2 = g_quark_to_string((( NAIExporterFileParms * ) parms )->format );
+                       writer->private->fn_str = find_export_format_fn_from_quark((( FMAIExporterFileParms * 
) parms )->format );
+                       format2 = g_quark_to_string((( FMAIExporterFileParms * ) parms )->format );
                } else {
                        writer->private->fn_str = find_export_format_fn( parms->format );
                        format2 = parms->format;
@@ -365,12 +365,12 @@ naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2
                writer->private->buffer = NULL;
 
                if( !writer->private->fn_str ){
-                       code = NA_IEXPORTER_CODE_INVALID_FORMAT;
+                       code = FMA_IEXPORTER_CODE_INVALID_FORMAT;
 
                } else {
                        code = writer_to_buffer( writer );
 
-                       if( code == NA_IEXPORTER_CODE_OK ){
+                       if( code == FMA_IEXPORTER_CODE_OK ){
                                filename = get_output_fname( parms->exported, parms->folder, format2 );
 
                                if( filename ){
@@ -953,7 +953,7 @@ writer_to_buffer( NAXMLWriter *writer )
        xmlChar *text;
        int textlen;
 
-       code = NA_IEXPORTER_CODE_OK;
+       code = FMA_IEXPORTER_CODE_OK;
        doc = build_xml_doc( writer );
 
        xmlDocDumpFormatMemoryEnc( doc, &text, &textlen, "UTF-8", 1 );
@@ -266,13 +266,13 @@ instance_finalize( GObject *object )
 /**
  * naxml_writer_export_to_buffer:
- * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterBufferParmsv2 structure.
+ * @instance: this #FMAIExporter instance.
+ * @parms: a #FMAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
@@ -322,13 +322,13 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
 /**
  * naxml_writer_export_to_file:
- * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterFileParmsv2 structure.
+ * @instance: this #FMAIExporter instance.
+ * @parms: a #FMAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.